@@ -399,10 +399,7 @@ fn realize_lw(
     // all data is word-aligned right now, and `offset_to_id` returns the offset in bytes
     let offset_bytes = data_section.offset_to_id(data_id) as u64;
     let offset_words = offset_bytes / 8;
-    let offset = match VirtualImmediate12::new(offset_words, Span {
-        span: pest::Span::new(" ".into(), 0, 0).unwrap(),
-        path: None
-    }) {
+    let offset = match VirtualImmediate12::new(offset_words, Span::new(" ".into(), 0, 0, None).unwrap()) {
         Ok(value) => value,
         Err(_) => panic!("Unable to offset into the data section more than 2^12 bits. Unsupported data section length.")
     };
