@@ -833,10 +833,7 @@ impl VirtualOp {
                     *offset_map
                         .get(&(i.value as u64))
                         .expect("new offset should be valid") as u64,
-                    crate::span::Span {
-                        span: pest::Span::new(" ".into(), 0, 0).unwrap(),
-                        path: None,
-                    },
+                    crate::span::Span::new(" ".into(), 0, 0, None).unwrap(),
                 )
                 .unwrap(),
             ),
@@ -847,10 +844,7 @@ impl VirtualOp {
                     *offset_map
                         .get(&(i.value as u64))
                         .expect("new offset should be valid") as u64,
-                    crate::span::Span {
-                        span: pest::Span::new(" ".into(), 0, 0).unwrap(),
-                        path: None,
-                    },
+                    crate::span::Span::new(" ".into(), 0, 0, None).unwrap(),
                 )
                 .unwrap(),
             ),
